@@ -1,7 +1,8 @@
-from .abc import BaseSlashCommandOption
+from .slash_command import Subcommand, SubCommandGroup, StringOption, IntegerOption, BooleanOption, UserOption, ChannelOption, RoleOption, MentionableOption, NumberOption
 from typing import (
     Optional,
-    List
+    List,
+    Union
 )
 
 class Section:
@@ -14,7 +15,7 @@ class Section:
             self.events[event_name] = func
         return register_event
 
-    def slash_command(self,*, name: str, description: Optional[str], options: List[BaseSlashCommandOption]):
+    def slash_command(self,*, name: str, description: Optional[str], options: List[Union[Subcommand, SubCommandGroup, StringOption, IntegerOption, BooleanOption, UserOption, ChannelOption, RoleOption, MentionableOption, NumberOption]]):
         def register_slash_command(func):
             self.commands[name] = {
                 "callback": func,
